# TeleTrader API Proxy

A small proxy which converts the proprietary TeleTrader API format to JSON.

## How to use

After building the program, you can access its API at `127.0.0.1:3030/{endpoint}`. You can change the default binding by
passing it as a program variable, e.g. `./teletrader-api-proxy 0.0.0.0:3030`.

### Available Endpoints

`/teletrader/{id}`: returns the daily history of the provided stock / ETF / ...

`/tts/{tts}`: alias for `/teletrader/tts-{tts}`

### Response

```json5
{
  "copyright": "This data is property of baha or the respective licensor. The terms of use can be accessed at https://www.teletrader.com/teletrader-products/terms_black",
  "data": [
    {
      "date": "2018-06-19T12:00:00Z",
      // Date according to ISO 8601
      "price": 6.136,
      // Latest price
      "high": 6.136,
      // Highest price on that date 
      "low": 6.136,
      // Lowest price on that date
      "volume": 0
      // Volume traded
    }
  ]
}
```

### Example: Portfolio Performance

![portfolio-performance-example](portfolio-performance.png)

### How to get the TeleTrader ID

1. Go to https://www.teletrader.com/
2. Search for the desired stock / ETF / ... by ISIN or WKN
3. Select the stock on the matching stock exchange
4. The URL should look something like
   this: `https://www.teletrader.com/frank-l-q-ac-a-xj-etf-dld/stocks/details/tts-159740499/name/asc`. In this
   case, `tts-159740499` would be the ID or when using the `/tts/` endpoint, `159740499` would be the TTS.

## Building

### Prerequistites

* [Rust](https://doc.rust-lang.org/cargo/getting-started/installation.html)

### Steps

1. `cargo build --release`

## Disclaimer

The author of this project does not claim responsibility for any damage caused by using this program. This source code
was solely published because of educational purposes. Please refer to TeleTrader's ToS available
at https://www.teletrader.com/teletrader-products/terms_black. This program is not endorsed by baha GmbH or any of its
subsidiaries. TeleTrader is a brand from baha GmbH.

## License

This project is licensed under either the

* [Apache License v2](LICENSE-APACHE)
* [MIT](LICENSE-MIT)

at your choice.
