#[macro_use]
extern crate log;
#[macro_use]
extern crate serde;

use std::net::SocketAddr;

use log::LevelFilter;
use warp::Filter;

mod teletrader;

#[tokio::main]
async fn main() {
    env_logger::builder()
        .filter_level(LevelFilter::Info)
        .parse_default_env()
        .init();

    let bind_to = std::env::args()
        .nth(1)
        .unwrap_or_else(|| "127.0.0.1:3030".to_string());

    let bind_to: SocketAddr = match bind_to.parse() {
        Ok(bind_to) => bind_to,
        Err(err) => {
            error!(
                "Provided argument couldn't be parsed to an address: {:?}",
                err
            );
            return;
        }
    };

    let tts = warp::path!("tts" / String).and_then(teletrader::proxy_tts);
    let miscellaneous = warp::path!("teletrader" / String).and_then(teletrader::proxy);

    warp::serve(tts.or(miscellaneous)).run(bind_to).await;
    info!("Started server!");
}
